- Limit the text to max 150 words.
- There is no set template for an Agile epic (`Epic` ticket type). You can write it in any way you
  like as long as it helps with planning your work and communication with your
  Agile teams and stakeholders. Here are some tips:
  - Epics can be used for filtering, grouping, and reporting. Therefore choosing
    a name that speaks for itself is important.
  - Not too big. A few weeks to a a few months.
  - Include success metrics if possible.
  - Include the big user story

  So for the `description` you can use:

  ```jira
  [include here the description, written in any way you like]

  h4. Success metric
  [include here the description, written in any way you like]

  h4. Big user story
  [include here the description, written in any way you like]

  As a .... I want to .... so that ....
  ```
